@@ -41,16 +41,10 @@ from __future__ import annotations
 from dataclasses import _MISSING_TYPE, Field, asdict, dataclass, is_dataclass
 
 # Types
-from typing import (
-    Any,
-    Callable,
-    Generator,
-    Optional,
-    Type,
-    TypeVar,
-    Union,
-    get_type_hints,
-)
+from typing import Any, Generator, Optional, Type, TypeVar, Union, get_type_hints
+
+# Others
+from typing_extensions import Protocol
 
 # Local
 from .config import Config, Option, SConfig
@@ -59,7 +53,12 @@ A = TypeVar("A")
 B = TypeVar("B")
 
 
-def from_dataclass(config: Type, ns: Optional[dict[str, Any]] = None) -> Config:
+class DC(Protocol):
+    """Dataclass protocol."""
+
+    __dataclass_fields__: dict
+
+def from_dataclass(config: DC, ns: Optional[dict[str, Any]] = None) -> Config:
     """Build config from dataclass."""
     if not is_dataclass(config):
         raise TypeError("config must be a dataclass.")
@@ -69,20 +68,20 @@ def from_dataclass(config: Type, ns: Optional[dict[str, Any]] = None) -> Config:
     )
 
 
-def _build_option(x: str, dc: Type, ns: Optional[dict[str, Any]] = None) -> Option:
+def _build_option(x: str, dc: DC, ns: Optional[dict[str, Any]] = None) -> Option:
     return Option(
         f"--{x}", default=getattr(dc, x), type=get_type_hints(dc, globalns=ns)[x]
     )
 
 
-def _build_sconfig(x: str, dc: Type, ns: Optional[dict[str, Any]] = None) -> SConfig:
+def _build_sconfig(x: str, dc: DC, ns: Optional[dict[str, Any]] = None) -> SConfig:
     if not is_dataclass(dc):
         raise TypeError("dc must be a dataclass.")
     return SConfig(x, None, *_build_options(getattr(dc, x), ns))
 
 
 def _build_options(
-    dc: Type, ns: Optional[dict[str, Any]] = None
+    dc: DC, ns: Optional[dict[str, Any]] = None
 ) -> Generator[Union[SConfig, Option], None, None]:
     for x in dc.__dataclass_fields__:
         if is_dataclass(x):
